<%inherit file="../base/base.html" /> <%namespace file="../base/base.html" import="header, setup_margin_labels" /> <%block name="extra_meta"> ${ setup_margin_labels(title) }
${ header(complete_header, title, report.get_subtitle(), notes) } <%include file="production-details.html" /> <%include file="production-items.html" /> <%include file="production-material.html" /> <%include file="production-services.html" />